.. title: Support and Contact
.. slug: contact
.. date: 1970-01-01 15:00:00
.. description: Get help using Nikola, or contact us.
.. author: The Nikola Team

:Version: 8.2.4

.. class:: alert alert-primary float-md-right

.. contents::

Help and Support
================

1. A `mailing list`_, nikola-discuss on Google Groups exists.
2. There’s an IRC channel: #nikola on Libera.Chat.  You can
   find many developers and volunteers (users) there which are there to provide
   help, if they are around and read your message.  The channels are
   `publicly logged <https://irclogs.getnikola.com/>`_.
3. You can also contact `@GetNikola <https://twitter.com/GetNikola>`_ on
   Twitter.
4. If you are experiencing a bug, you should report it on GitHub (see
   below).

Plugins and Themes
------------------

Plugins and Themes from the Indexes are not officially supported.

1. Ask the `mailing list`_, which may or may not work out.
2. You can also try the IRC channel if the theme/plugin is very popular.
3. Report an issue at the `plugins issue tracker`_ or at the `themes
   issue tracker`_.
4. Contact the author of the plugin/theme.  The name of the author of a
   plugin is available in the ``.plugin`` and ``.py`` files.  Tracking
   down theme authors can be much harder due to how our architecture
   works (but certainly is doable).

Report a Bug, Request a Feature
===============================

Bug reports should be sent to the `Issue tracker`_ at GitHub.

Feature requests should be sent to the `Issue tracker`_ or to
the `mailing list`_, especially if they require further discussion.

Administrativia
===============

If you are in need of getting administrativia resolved, you may want
to e-mail info@getnikola.com and therefore contact the people behind the
project.  Note that this email **may not** be used for support matters.
Messages are forwarded to all three administrators, the names and
personal addresses (if you need to contact them personally) of you can
find below.

Administrators
--------------

.. class:: table table-bordered

+----------------------+-----------------+-----------+-----------------------+
| Name                 | GitHub Nickname | Location  | E-mail                |
+======================+=================+===========+=======================+
| Roberto Alsina       | ralsina         | Argentina | roberto@getnikola.com |
+----------------------+-----------------+-----------+-----------------------+
| Damián Avila         | damianavila     | Argentina | damian@getnikola.com  |
+----------------------+-----------------+-----------+-----------------------+
| Daniel Aleksandersen | Aeyoun          | Norway    | daniel@getnikola.com  |
+----------------------+-----------------+-----------+-----------------------+
| Chris Warrick        | Kwpolska        | Poland    | chris@getnikola.com   |
+----------------------+-----------------+-----------+-----------------------+

.. _mailing list: https://groups.google.com/group/nikola-discuss
.. _Issue tracker: https://github.com/getnikola/nikola/issues
.. _plugins issue tracker: https://github.com/getnikola/plugins/issues
.. _themes issue tracker: https://github.com/getnikola/nikola-themes/issues
